#' The 'LMMELSM' package.
#'
#' @description Fits latent (or observed) multivariate (or univariate) mixed effects location scale models.
#'
#' @name LMMELSM-package
#' @aliases LMMELSM
#' @useDynLib LMMELSM, .registration = TRUE
#' @import methods
#' @import Rcpp
#' @importFrom rstan sampling
#'
#' @references
#' Stan Development Team (2020). RStan: the R interface to Stan. R package version 2.19.3. https://mc-stan.org
#' @keywords internal
"_PACKAGE"
